==> moodle-1.9.7.tgz: moodle/lang/en_utf8/enrol_mnet.php <==
<?php

$string['description'] = 'Description of enrolment over Moodle Networking.';
$string['enrolname'] = 'Moodle Networking';
$string['allow_allcourses'] = 'Allow enrolment in all remote courses.';
$string['allcategories'] = '$a potential categories';
$string['allowedcategories'] = '$a allowed categories';
$string['nocategoriesdefined'] = 'No course categories found. Define new categories <a href=\"$a\">here</a>.';
$string['allcourses'] = '$a potential courses';
$string['allowedcourses'] = '$a allowed courses';
$string['nocoursesdefined'] = 'No courses found. Define new courses <a href=\"$a\">here</a>.';
$string['allowedcourseslinktext'] = 'Edit allowed courses and categories here.';
$string['mnet_enrol_name']             = 'Moodle Networked Enrolment';
$string['mnet_enrol_description']      = 'Publish this service to allow administrators at $a to enrol their students in courses you have created on your server.<br/>' .
                                         '<ul><li><em>Dependency</em>: You must also <strong>publish</strong> the SSO (Service Provider) service to $a.</li>'.
                                         '<li><em>Dependency</em>: You must also <strong>subscribe</strong> to the SSO (Identity Provider) service on $a.</li></ul><br/>'.
                                         'Subscribe to this service to be able to enrol your students in courses  on $a.<br/>'.
                                         '<ul><li><em>Dependency</em>: You must also <strong>subscribe</strong> to the SSO (Service Provider) service on $a.</li>'.
                                         '<li><em>Dependency</em>: You must also <strong>publish</strong> the SSO (Identity Provider) service to $a.</li></ul><br/>';
$string['mnetlocalforexternal'] = 'Local courses for external users';

?>

==> moodle-1.9.16.tgz: moodle/lang/en_utf8/enrol_mnet.php <==
<?php

$string['description'] = 'The MNET enrolment plugin allows networked sites to enrol their users on some or all of the courses on this moodle site.';
$string['enrolname'] = 'Moodle Networking';
$string['allow_allcourses'] = 'Allow enrolment in all remote courses.';
$string['allow_allcourses2'] = 'Allow enrolment for remote users in all courses on this moodle site.';
$string['allcategories'] = '$a potential categories';
$string['allowedcategories'] = '$a allowed categories';
$string['nocategoriesdefined'] = 'No course categories found. Define new categories <a href=\"$a\">here</a>.';
$string['allcourses'] = '$a potential courses';
$string['allowedcourses'] = '$a allowed courses';
$string['nocoursesdefined'] = 'No courses found. Define new courses <a href=\"$a\">here</a>.';
$string['allowedcourseslinktext'] = 'Edit allowed courses and categories here.';
$string['mnet_enrol_name']             = 'Moodle Networked Enrolment';
$string['mnet_enrol_description']      = 'Publish this service to allow administrators at $a to enrol their students in courses you have created on your server.<br/>' .
                                         '<ul><li><em>Dependency</em>: You must also <strong>publish</strong> the SSO (Service Provider) service to $a.</li>'.
                                         '<li><em>Dependency</em>: You must also <strong>subscribe</strong> to the SSO (Identity Provider) service on $a.</li></ul><br/>'.
                                         'Subscribe to this service to be able to enrol your students in courses  on $a.<br/>'.
                                         '<ul><li><em>Dependency</em>: You must also <strong>subscribe</strong> to the SSO (Service Provider) service on $a.</li>'.
                                         '<li><em>Dependency</em>: You must also <strong>publish</strong> the SSO (Identity Provider) service to $a.</li></ul><br/>';
$string['mnetlocalforexternal'] = 'Local courses for external users';

?>
